==> json-io-4.19.0-sources.jar: com/cedarsoftware/util/io/Primitives.java <==
package com.cedarsoftware.util.io;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

public class Primitives {

    static final Set<Class<?>> PRIMITIVE_WRAPPERS = new HashSet<>();

    static final Set<Class<?>> NATIVE_JSON_TYPES = new HashSet<>();

    static {
        PRIMITIVE_WRAPPERS.add(Byte.class);
        PRIMITIVE_WRAPPERS.add(Integer.class);
        PRIMITIVE_WRAPPERS.add(Long.class);
        PRIMITIVE_WRAPPERS.add(Double.class);
        PRIMITIVE_WRAPPERS.add(Character.class);
        PRIMITIVE_WRAPPERS.add(Float.class);
        PRIMITIVE_WRAPPERS.add(Boolean.class);
        PRIMITIVE_WRAPPERS.add(Short.class);

        NATIVE_JSON_TYPES.add(Long.class);
        NATIVE_JSON_TYPES.add(long.class);
        NATIVE_JSON_TYPES.add(Double.class);
        NATIVE_JSON_TYPES.add(double.class);
        NATIVE_JSON_TYPES.add(String.class);
        NATIVE_JSON_TYPES.add(Boolean.class);
        NATIVE_JSON_TYPES.add(boolean.class);
        NATIVE_JSON_TYPES.add(Object[].class);
        //NATIVE_JSON_TYPES.add(LinkedHashMap.class);
    }

    /**
     * Statically accessed class, no need for Construction
     */
    private Primitives() {
    }
    
    /**
     * @param c Class to test
     * @return boolean true if the passed in class is a Java primitive, false otherwise.  The Wrapper classes
     * Integer, Long, Boolean, etc. are considered primitives by this method.
     */
    public static boolean isPrimitive(Class<?> c) {
        return c.isPrimitive() || PRIMITIVE_WRAPPERS.contains(c);
    }

    /**
     * @param c Class to test
     * @return boolean true if the passed in class is a Java primitive, false otherwise.  The Wrapper classes
     * Integer, Long, Boolean, etc. are considered primitives by this method.
     */
    public static boolean isJsonType(Class<?> c) {
        return NATIVE_JSON_TYPES.contains(c);
    }

    /**
     * @param c Class to test
     * @param logicalPrimitives - set of logical primitives
     * @return boolean true if the passed in class is a 'logical' primitive.  A logical primitive is defined
     * as all Java primitives, the primitive wrapper classes, String, Number, and Date.  This covers BigDecimal,
     * BigInteger, AtomicInteger, AtomicLong, as these are 'Number instances. The reason these are considered
     * 'logical' primitives is that they are immutable and therefore can be written without references in JSON
     * content (making the JSON more readable - less @id / @ref), without breaking the semantics (shape) of the
     * object graph being written.
     */
    public static boolean isLogicalPrimitive(Class<?> c, Set<Class<?>> logicalPrimitives) {
        return c.isPrimitive() ||
                logicalPrimitives.contains(c) ||
                String.class.isAssignableFrom(c) ||
                Number.class.isAssignableFrom(c) ||
                Date.class.isAssignableFrom(c) ||
                c.isEnum() ||
                c.equals(Class.class);
    }

}

==> json-io-4.19.7-sources.jar: com/cedarsoftware/util/io/Primitives.java <==
package com.cedarsoftware.util.io;

import java.util.HashSet;
import java.util.Set;

public class Primitives {
    static final Set<Class<?>> PRIMITIVE_WRAPPERS = new HashSet<>();
    static final Set<Class<?>> NATIVE_JSON_TYPES = new HashSet<>();

    static {
        PRIMITIVE_WRAPPERS.add(Byte.class);
        PRIMITIVE_WRAPPERS.add(Integer.class);
        PRIMITIVE_WRAPPERS.add(Long.class);
        PRIMITIVE_WRAPPERS.add(Double.class);
        PRIMITIVE_WRAPPERS.add(Character.class);
        PRIMITIVE_WRAPPERS.add(Float.class);
        PRIMITIVE_WRAPPERS.add(Boolean.class);
        PRIMITIVE_WRAPPERS.add(Short.class);

        // Native json types are the types we can leave the type value off of now matter what
        // and it will always come in correct, so even if its in an object array it will be the correct type
        // after deserialization.  I had to leave JsonObject, even though that is our default
        // map type because we use it to build the object so it shows up for every object, not just types that could be JsonObject.
        // If we had our default type be LinkedHashMap instead of JsonObject we could always convert to that type when no type
        // data was present.  that requires more conversion, though, and could take longer over all when working with JSON_OBJECTS.
        // but we are doing something similar with Object[] because we build it with an ArrayList type and then convert to array.
        // we could have our default there be array list when representing the array type in JSON.
        NATIVE_JSON_TYPES.add(Long.class);
        NATIVE_JSON_TYPES.add(long.class);
        NATIVE_JSON_TYPES.add(Double.class);
        NATIVE_JSON_TYPES.add(double.class);
        NATIVE_JSON_TYPES.add(String.class);
        NATIVE_JSON_TYPES.add(Boolean.class);
        NATIVE_JSON_TYPES.add(boolean.class);
        NATIVE_JSON_TYPES.add(Object[].class);
    }

    /**
     * Statically accessed class, no need for Construction
     */
    private Primitives() {
    }
    
    /**
     * @param c Class to test
     * @return boolean true if the passed in class is a Java primitive, false otherwise.  The Wrapper classes
     * Integer, Long, Boolean, etc. are considered primitives by this method.
     */
    public static boolean isPrimitive(Class<?> c) {
        return c.isPrimitive() || PRIMITIVE_WRAPPERS.contains(c);
    }

    /**
     * @param c Class to test
     * @return boolean true if the passed in class is a Java primitive, false otherwise.  The Wrapper classes
     * Integer, Long, Boolean, etc. are considered primitives by this method.
     */
    public static boolean isNativeJsonType(Class<?> c) {
        return NATIVE_JSON_TYPES.contains(c);
    }
}
